@@ -4,19 +4,19 @@
 ** Author: Peter Eriksson <pen@lysator.liu.se>
 */
 
-#ifdef NeXT3
-#  include <libc.h>
+#if HAVE_CONFIG_H
+# include "config.h"
 #endif
+#include <stdlib.h>
 
-#ifdef HAVE_ANSIHEADERS
-#  include <stdlib.h>
-#  include <unistd.h>
+#if HAVE_UNISTD_H
+# include <unistd.h>
 #endif
 
 #define IN_LIBIDENT_SRC
 #include "ident.h"
 
-int id_close __P1(ident_t *, id)
+int id_close (ident_t *id)
 {
     int res;
   
@@ -25,5 +25,3 @@ int id_close __P1(ident_t *, id)
     
     return res;
 }
-
-
