@@ -4,43 +4,30 @@
 ** Author: Pr Emanuelsson <pell@lysator.liu.se>, 28 March 1993
 */
 
-#ifdef NeXT3
-#  include <libc.h>
+#if HAVE_CONFIG_H
+# include "config.h"
 #endif
 
-#include <errno.h>
-
-#ifdef HAVE_ANSIHEADERS
-#  include <stdlib.h>
-#  include <unistd.h>
-#endif
-
-#include <sys/types.h>
-
-/* Need this to make fileno() visible when compiling with strict ANSI */
-#ifndef _POSIX_C_SOURCE
-#  define _POSIX_C_SOURCE
-#endif
 #include <stdio.h>
 
 #define IN_LIBIDENT_SRC
 #include "ident.h"
 
-void
-main __P2(int, argc,
-	  char **, argv)
+int main (int argc, char *argv[])
 {
   IDENT *ident;
   char *user;
 
-  chdir("/tmp");
+  /* 
+   * We can't use puts() because it send LF instead of CRLF
+   * Note that perror() does not work properly either.
+   */
+  printf("Welcome to the other IDENT server tester, version 1.1\r\n\r\n");
 
-  puts("Welcome to the other IDENT server tester, version 1.0\r\n\r");  
-
-  puts("Testing ident_lookup...\r\n\r");
+  printf("Testing ident_lookup...\r\n\r\n");
   fflush(stdout);
 
-  ident = ident_lookup(fileno(stdin), 30);
+  ident = ident_lookup(0, 30);
 
   if (!ident)
     perror("ident");
@@ -56,7 +43,7 @@ main __P2(int, argc,
 
   ident_free(ident);
 
-  puts("\r\nTesting ident_id...\r\n\r");
+  printf("\r\nTesting ident_id...\r\n\r\n");
   fflush(stdout);
 
   user = ident_id(fileno(stdin), 30);
@@ -64,10 +51,8 @@ main __P2(int, argc,
   if (user)
     printf("IDENT response is identifier = %s\r\n", user);
   else
-    puts("IDENT lookup failed!\r");
+    perror("IDENT lookup failed");
 
   fflush(stdout);
-  sleep(1);
-  exit(0);
+  return 0;
 }
-
