@@ -6,19 +6,14 @@
 */
 #include <stdio.h>
 #include <ctype.h>
-
-#ifdef HAVE_ANSIHEADERS
-#  include <stdlib.h>
-#  include <string.h>
-#else
-#  define strchr(str, c) index(str, c)
-#endif
+#include <stdlib.h>
+#include <string.h>
 
 #define IN_LIBIDENT_SRC
 #include "ident.h"
 
 
-char *id_strdup __P1(char *, str)
+char *id_strdup (char *str)
 {
     char *cp;
 
@@ -37,9 +32,7 @@ char *id_strdup __P1(char *, str)
 }
 
 
-char *id_strtok __P3(char *, cp,
-		      char *, cs,
-		      char *, dc)
+char *id_strtok (char *cp, char *cs, char *dc)
 {
     static char *bp = 0;
     
